@@ -50,9 +50,9 @@ void open_all(void)
 	diag(COMPONENT,DIAG_FATAL,"setsockopt SO_ATMQOS: %s",strerror(errno));
     memset(&addr,0,sizeof(addr));
     addr.sas_family = AF_ATMSVC;
-    addr.sas_addr.bhli.hl_type = ATM_HL_USER;
-    addr.sas_addr.bhli.hl_length = strlen("AREQ");
-    strcpy(addr.sas_addr.bhli.hl_info,"AREQ");
+    addr.sas_addr.bhli.hl_type = ATM_HL_VENDOR;
+    addr.sas_addr.bhli.hl_length = 7;
+    memcpy(addr.sas_addr.bhli.hl_info,AREQUIPA_HLT_VS_ID,7);
     addr.sas_addr.blli = &blli;
     blli.l2_proto = ATM_L2_ISO8802;
     blli.l3_proto = ATM_L3_NONE;
