@@ -450,6 +450,7 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
     }
     else {
 	entry = alloc_entry(1);
+	entry->flags = ATF_PUBL;
 	if (vcc) {
 	    vcc->entry = entry;
 	    Q_INSERT_HEAD(entry->vccs,vcc);
@@ -531,6 +532,7 @@ void need_ip(int itf_num,unsigned long ip)
 	}
     else {
 	entry = alloc_entry(1);
+	entry->flags = ATF_PUBL;
 	entry->ip = ip;
 	entry->itf = itf;
 	Q_INSERT_HEAD(itf->table,entry);
@@ -644,8 +646,9 @@ void incoming_arp(VCC *vcc,struct atmarphdr *hdr,int len)
 	    entry = NULL;
 	    itf = lookup_itf_by_ip(tgt_ip);
 	    entry = itf ? lookup_ip(itf,tgt_ip) : NULL;
-	    if (!entry) arp_nak(vcc,tgt_ip,src_ip,&source);
-	    else arp_reply(vcc,tgt_ip,entry->addr,src_ip,&source);
+	    if (entry && entry->state == as_valid && (entry->flags & ATF_PUBL))
+		arp_reply(vcc,tgt_ip,entry->addr,src_ip,&source);
+	    else arp_nak(vcc,tgt_ip,src_ip,&source);
 	    break;
 	case ARPOP_REPLY:
 	    diag(COMPONENT,DIAG_DEBUG,"got ARP_REP");
@@ -766,6 +769,15 @@ static int ioctl_delete(ITF *itf,unsigned long ip,int flags)
 }
 
 
+static void adjust_qos(ITF *itf,struct atm_qos *qos,int null_encap)
+{
+    if (!qos->txtp.max_sdu)
+	qos->txtp.max_sdu = RFC1626_MTU+(null_encap ? 0 : RFC1483LLC_LEN);
+    if (!qos->rxtp.max_sdu)
+	qos->rxtp.max_sdu = RFC1626_MTU+(null_encap ? 0 : RFC1483LLC_LEN);
+}
+
+
 int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req)
 {
     ITF *itf;
@@ -775,7 +787,7 @@ int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req)
 
     diag(COMPONENT,DIAG_DEBUG,"arp_ioctl 0x%08lx",cmd);
     if (req->arp_pa.sa_family != AF_INET) {
-	diag(COMPONENT,DIAG_ERROR,"SIOCSARP: bad PA AF 0x%x",
+	diag(COMPONENT,DIAG_ERROR,"SIOCxARP: bad PA AF 0x%x",
 	  req->arp_pa.sa_family);
 	return -EPFNOSUPPORT;
     }
@@ -797,10 +809,12 @@ int arp_ioctl(int itf_num,unsigned long cmd,struct atmarpreq *req)
 	      req->arp_flags);
 	    switch (req->arp_ha.sas_family) {
 		case AF_ATMPVC:	
+		    adjust_qos(itf,&req->arp_qos,req->arp_flags & ATF_NULL);
 		    return ioctl_set_pvc(itf,((struct sockaddr_in *)
 		      &req->arp_pa)->sin_addr.s_addr,(struct sockaddr_atmpvc *)
 		      &req->arp_ha,&req->arp_qos,req->arp_flags);
 		case AF_ATMSVC:
+		    adjust_qos(itf,&req->arp_qos,0);
 		    return ioctl_set_svc(itf,((struct sockaddr_in *)
 		      &req->arp_pa)->sin_addr.s_addr,(struct sockaddr_atmsvc *)
 		      &req->arp_ha,&req->arp_qos,req->arp_flags);
