@@ -55,7 +55,7 @@ void itf_up(int number)
 	    return;
 	}
     itf = alloc_t(ITF);
-    if (ip_itf_info(number,&itf->local_ip,&itf->netmask) < 0) {
+    if (ip_itf_info(number,&itf->local_ip,&itf->netmask,&itf->mtu) < 0) {
 	free(itf);
 	return;
     }
