@@ -109,10 +109,14 @@ static void dump_vcc(VCC *vcc)
 
 static void dump_entries(ENTRY *list)
 {
+    static const char *flag_name[] = { "???","com","PERM","PUBL","trailers",
+      "netmask","NULL","ARPSRV" }; /* lower case flags are not used by ATMARP */
     ENTRY *entry;
     VCC *vcc;
     char buffer[MAX_ATM_ADDR_LEN+1];
+    char tmp[100]; /* large enough for all flags */
     unsigned char *ipp;
+    int i;
 
     for (entry = list; entry ; entry = entry->next) {
 	if (!entry->addr) strcpy(buffer,"<none>");
@@ -120,8 +124,15 @@ static void dump_entries(ENTRY *list)
 	      (struct sockaddr *) entry->addr,pretty) < 0)
 		strcpy(buffer,"<error>");
 	ipp = (unsigned char *) &entry->ip;
-	output("IP %d.%d.%d.%d, state %s, addr %s, flags 0x%x",ipp[0],ipp[1],
-	  ipp[2],ipp[3],entry_state_name[entry->state],buffer,entry->flags);
+	*tmp = 0;
+	for (i = 0; i < 8; i++)
+	    if (entry->flags & (1 << i)) {
+		if (*tmp) strcat(tmp,",");
+		strcat(tmp,flag_name[i]);
+	    }
+	output("IP %d.%d.%d.%d, state %s, addr %s, flags 0x%x<%s>",ipp[0],
+	  ipp[1],ipp[2],ipp[3],entry_state_name[entry->state],buffer,
+	  entry->flags,tmp);
 	for (vcc = entry->vccs; vcc; vcc = vcc->next) dump_vcc(vcc);
     }
 }
