@@ -238,7 +238,7 @@ if ($t =~ /[$X$Y$Z$B$E]/) {
 print STDERR "[".length($t)."] Processing simple tables\n";
 while ($t =~ /\\begin{tabular}/) { $t = $`.$B.$'; }
 while ($t =~ /\\end{tabular}/) { $t = $`.$E.$'; }
-while ($t =~ /$B{([rlc|]+)}([^$B$E]*)$E/) {
+while ($t =~ /$B\{([rlc|]+)\}([^$B$E]*)$E/) {
     ($a,$b,$c,$d) = ($`,$',$2,$1);
     $c =~ s/\\\\/&/g;
     $c =~ s/[\s\n]*\\hline[\s\n]*/$X&/g;
@@ -336,7 +336,7 @@ while ($t =~ /\\label{/) { $t = $`.$LB."{".$'; }
 while ($t =~ /\\((sub)*)section{/) { $t = $`.$SC.$1."{".$'; }
 $l = "";
 while (1) {
-    if ($t =~ /^([^$LB$SC]*)$LB{([^{}]*)}/) {
+    if ($t =~ /^([^$LB$SC]*)$LB\{([^{}]*)\}/) {
 	$l{$2} = '"'.$l.'"';
 	$t = $1.$';
     }
@@ -399,8 +399,8 @@ print STDERR "[".length($t)."] Applying ultimate set of fixes to newlines\n";
 while ($t =~ s/([\n$B1$B2]+)([$SI$SO])/$2$1/g) {};
 $t =~ s/([\n$B1$B2]*)\s+([\n$B1$B2]+)/$1$2/g;
 $t =~ s/\n+/\n/g;
-$t =~ s/\n?$B1[\n$B1]*/\n\n/g;
-$t =~ s/\n*$B2[\n$B2]*/\n\n\n/g;
+$t =~ s/\n?($B1)[\n$B1]*/\n\n/g;
+$t =~ s/\n*($B2)[\n$B2]*/\n\n\n/g;
 #
 # translate what's left
 #
