@@ -20,7 +20,7 @@
 #include <linux/atmarp.h>
 #include <linux/atmclip.h>
 #include <linux/netdevice.h> /* for MAX_ADDR_LEN for if_arp.h */
-#include <linux/if_arp.h> /* for ATF_PERM */
+#include <linux/if_arp.h> /* for ATF_PERM and ATF_PUBL */
 
 #include "atm.h"
 
@@ -56,10 +56,10 @@ static void usage(const char *name)
 {
     fprintf(stderr,"usage: %s -a\n",name);
     fprintf(stderr,"%6s %s -c [[atm]N]\n","",name);
-    fprintf(stderr,"%6s %s -s ip_addr [itf.]vpi.vci [pcr value] [temp] [null]"
-      "\n","",name);
-    fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [temp] [arpsrv]\n",
-     "",name);
+    fprintf(stderr,"%6s %s -s ip_addr [itf.]vpi.vci [pcr value] [temp] [pub]"
+      " [null]\n","",name);
+    fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [temp] [pub] "
+      "[arpsrv]\n","",name);
     fprintf(stderr,"%6s %s -d ip_addr [arpsrv]\n","",name);
     exit(1);
 }
@@ -151,6 +151,7 @@ int main(int argc,char **argv)
 	req.arp_qos.txtp.traffic_class = ATM_UBR;
 	for (i = optind+2; i < argc; i++)
 		if (!strcmp(argv[i],"temp")) req.arp_flags &= ~ATF_PERM;
+		else if (!strcmp(argv[i],"pub")) req.arp_flags |= ATF_PUBL;
 		else if (!strcmp(argv[i],"null")) req.arp_flags |= ATF_NULL;
 		else if (!strcmp(argv[i],"arpsrv")) req.arp_flags |= ATF_ARPSRV;
 		else if (!strcmp(argv[i],"pcr")) {
@@ -159,7 +160,9 @@ int main(int argc,char **argv)
 			if (*end) usage(argv[0]);
 		    }
 		else usage(argv[0]);
+#if 0 /* atmarpd now sets max_sdu if 0 */
 	req.arp_qos.txtp.max_sdu = RFC1483LLC_LEN+RFC1626_MTU;
+#endif
 	req.arp_qos.rxtp = req.arp_qos.txtp;
 	if (text2atm(argv[optind+1],(struct sockaddr *) &req.arp_ha,
 	  sizeof(req.arp_ha),T2A_NAME) < 0) {
