@@ -120,6 +120,7 @@ typedef struct _Sap_client_t_ {
   unsigned long rcv_packet_count;
   unsigned long accept_packet_count;
   unsigned long reject_packet_count;
+  int itf_num;
   struct _Sap_client_t_ *next;
 } Sap_client_t;
 
@@ -140,6 +141,7 @@ cm_sap_register(HANDLE sap_context,
 		SAP_CONNECT_CALLBACK svc_connect_callback,
 		SAP_LINK_STATUS_CALLBACK link_status_callback,
 		SAP_XMT_DONE_CALLBACK xmt_done_callback,
+		int itf_num,
 		const char *p_sap_text, HANDLE *p_sap_handle)
 {
   Sap_client_t *client;
@@ -179,6 +181,8 @@ cm_sap_register(HANDLE sap_context,
   /* Statistic variables */
   client->xmt_packet_count = client->rcv_packet_count = 
     client->accept_packet_count = client->reject_packet_count = 0;
+
+  client->itf_num = itf_num;
   
   /* Link to place */
   client->next = clientlist;
@@ -278,6 +282,7 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
 		  HANDLE *p_conn_handle)
 {
   Conn_t *conn;
+  Sap_client_t *sap = (Sap_client_t *)sap_handle;
   int s;
   int ret;
   struct sockaddr_atmsvc us;
@@ -426,12 +431,12 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
     return STATUS_K_ATM_RESOURCES;
   }
 
-
   /* Notify lower layer. */
   switch (p_conn_info->blli.l3.tr9577.snap[4]) { /* AAAAAARRRGGHHH! */
   case 0x02:
   case 0x03:
     memcpy(ioc_data.atm_addr, p_conn_info->addr.sas_addr.prv, ATM_ESA_LEN);
+    ioc_data.dev_num = sap->itf_num;
     ioc_data.receive = 0;
     EVENT(EM_DEBUG,("About to ioctl(s, ATMLEC_DATA, &ioc_data)\n"));
     if (ioctl(s, ATMLEC_DATA, &ioc_data)<0) {
@@ -439,7 +444,7 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
 		     strerror(errno)));      
       if (is_data_direct(p_conn_info)) {
 	/* Try to remove possible entry in kernel */
-      lc_addr_delete(conn_context, p_conn_info->addr.sas_addr.prv);
+	lc_addr_delete(conn_context, p_conn_info->addr.sas_addr.prv);
       }
       close(s);
       *p_conn_handle = NULL;
@@ -449,7 +454,7 @@ cm_sap_svc_setup (HANDLE sap_handle, HANDLE conn_context,
     break;
   case 0x04:
   case 0x05:
-    if (ioctl(s, ATMLEC_MCAST)<0) {
+    if (ioctl(s, ATMLEC_MCAST, sap->itf_num)<0) {
       EVENT(EM_SERR,("Can't change socket into LE mcast socket:%s\n",
 		     strerror(errno)));
       if (is_data_direct(p_conn_info)) {
@@ -803,7 +808,7 @@ conn_check_incoming(fd_set *fds)
 		  ioc_data.receive = 0; /* Data direct */
 	      } else
 		ioc_data.receive = 2; /* Multicast distribute */
-	      
+	      ioc_data.dev_num = sap->itf_num;
 	      EVENT(EM_DEBUG,("About to ioctl(fd, ATMLEC_DATA, &ioc_data)\n"));
 	      if (ioctl(fd, ATMLEC_DATA, &ioc_data)<0) {
 		EVENT(EM_SERR,("Can't change socket into LE data socket:%s\n",
