@@ -26,7 +26,7 @@
  * Timer creation, setting and allocation. Protypes defined in
  * utl_os.h
  *
- * $Id: timers.c,v 1.8 1996/07/07 11:51:47 carnil Exp carnil $
+ * $Id: timers.c,v 1.9 1996/08/06 14:14:11 carnil Exp carnil $
  *
  */
 
@@ -241,9 +241,25 @@ timer_call_callback(HANDLE timer_handle)
     to_call->callback(to_call->context);
 }
 
+void 
+timer_usage(void)
+{
+  Timer_t *tmp;
+
+  printf("Timer usage:\n");
+  for(tmp=timerlist;tmp;tmp=tmp->next)
+    printf("\tCallback %p Context:%p %d sec %d usec\n",
+	   tmp->callback, tmp->context, 
+	   tmp->alarm_time?tmp->alarm_time->tv_sec:0,
+	   tmp->alarm_time?tmp->alarm_time->tv_usec:0);
+}
+
 /*
  *
  * $Log: timers.c,v $
+ * Revision 1.9  1996/08/06 14:14:11  carnil
+ * Cleaning up
+ *
  * Revision 1.8  1996/07/07 11:51:47  carnil
  * Global_msgmask
  *
