@@ -26,9 +26,9 @@ int arequipa_preset(int sd,const struct sockaddr_atmsvc *addr,
     }
     a = *addr;
     if (a.sas_family == AF_ATMSVC) {
-	a.sas_addr.bhli.hl_type = ATM_HL_USER;
-	a.sas_addr.bhli.hl_length = strlen("AREQ");
-	strcpy(a.sas_addr.bhli.hl_info,"AREQ");
+	a.sas_addr.bhli.hl_type = ATM_HL_VENDOR;
+	a.sas_addr.bhli.hl_length = 7;
+	memcpy(a.sas_addr.bhli.hl_info,AREQUIPA_HLT_VS_ID,7);
 	a.sas_addr.blli = &blli;
 	blli.l2_proto = ATM_L2_ISO8802;
 	blli.l3_proto = ATM_L3_NONE;
