@@ -60,34 +60,6 @@ void vdiag(const char *component,int severity,const char *fmt,va_list ap);
 void diag(const char *component,int severity,const char *fmt,...);
 
 
-/*----------- Quick and very very dirty buffer and queue handling -----------*/
-
-
-typedef struct _buffer {
-    void *data;
-    int length;
-    int key; /* SD.N(S) */
-    int extra; /* SD.N(PS) */
-    struct _buffer *next,*prev;
-} BUFFER;
-
-typedef struct {
-    BUFFER *first,*last;
-} QUEUE;
-
-
-BUFFER *buffer_create(int length,int key);
-BUFFER *buffer_clone(BUFFER *b);
-void buffer_discard(BUFFER *b);
-void queue_init(QUEUE *q);
-void queue_put(QUEUE *q,BUFFER *b);
-void queue_remove(QUEUE *q,BUFFER *b);
-BUFFER *queue_peek(QUEUE *q);
-BUFFER *queue_get(QUEUE *q);
-BUFFER *queue_lookup(QUEUE *q,int key);
-void queue_clear(QUEUE *q);
-
-
 /*------------------------------ Timer support ------------------------------*/
 
 
