@@ -301,4 +301,12 @@
 #define ATM_AALP_AAL_MODE	0x83 /* AAL mode (UNI 3.0 only) */
 #define ATM_AALP_SSCS		0x84 /* SSCS type */
 
+/* The following constants tag message parser errors. */
+
+#define RECOV_IND_IE		1	/* IE problem */
+
+/* The following constants tag application-specific errors. */
+
+#define RECOV_ASE_UNKNOWN_IE	1	/* unknown IE */
+
 #endif
