@@ -277,6 +277,14 @@ void poll_loop(void)
     gettimeofday(&now,NULL);
     while (1) {
 	set = perm;
+	poll_signals();
+	/*
+	 * Here we have a small race condition: if a signal is delivered after
+	 * poll_signals tests for it but before select sleeps, we miss that
+	 * signal. If it is sent again, we're of course likely to get it. This
+	 * isn't worth fixing, because those signals are only used for
+	 * debugging anyway.
+	 */
 	ret = select(fds,&set,NULL,NULL,next_timer());
 	if (ret < 0) {
 	    if (errno != EINTR) perror("select");
