@@ -59,9 +59,12 @@ extern const char *state_name[],*qs_name[],*as_name[];
 extern SOCKET *sockets;
 extern unsigned char q_buffer[];
 
+#define DEFAULT_TRACE_SIZE 20
+
 extern int net;
 extern int pretty;
 extern int sig_pcr;
+extern const char *dump_dir;
 
 
 #define msg2bllis(s) (((int) (s)-(int) sizeof(struct atmsvc_msg))/ \
@@ -72,6 +75,8 @@ extern int sig_pcr;
   send_kernel(vcc,0L,as_error,code,NULL,NULL,NULL,NULL)
 
 
+void poll_signals(void);
+
 void from_kernel(struct atmsvc_msg *msg,int size);
 void itf_load(int itf);
 
