@@ -37,7 +37,7 @@ int main(int argc,char **argv)
 	usage(argv[0]);
     offset = argc == 3 ? 0 : atoi(argv[3]);
     memset(&qos,0,sizeof(qos));
-    qos.txtp.class = ATM_UBR;
+    qos.txtp.traffic_class = ATM_UBR;
     qos.txtp.max_sdu = strlen(argv[2])-offset;
     if (setsockopt(s,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0) {
 	perror("setsockopt SO_ATMQOS");
