@@ -583,7 +583,7 @@ printf("sbs=%d\n",sockbufsize);
     if (realt <= 0.0)
 	realt = 0.001;
 
-    mbps = (double)(nbytes * 8) / realt / (1024.0 * 1024.0);
+    mbps = (double)(nbytes * 8) / realt / 1000000.0;
     fprintf(stdout,
 	    "ttcp%s: %.0f bytes in %f real seconds = %s/sec (%f Mb/sec)\n",
 	    trans?"-t":"-r",
@@ -604,7 +604,7 @@ printf("sbs=%d\n",sockbufsize);
 		"ttcp%s: %d I/O calls, msec/call = %.2f, calls/sec = %.2f\n",
 		trans?"-t":"-r",
 		numCalls,
-		1024.0 * realt/((double)numCalls),
+		1000.0 * realt/((double)numCalls),
 		((double)numCalls)/realt);
 	fprintf(stdout,
 		"ttcp%s: buffer address %#x\n",
